@@ -51,7 +51,7 @@ WaylandConfig::WaylandConfig(QObject *parent)
     initKWinTabletMode();
 
     connect(this, &WaylandConfig::initialized, &m_syncLoop, &QEventLoop::quit);
-    QTimer::singleShot(1000, this, [this] {
+    QTimer::singleShot(3000, this, [this] {
         if (m_syncLoop.isRunning()) {
             qCWarning(KSCREEN_WAYLAND) << "Connection to Wayland server at socket:"
                                        << m_connection->socketName() << "timed out.";
@@ -245,7 +245,8 @@ void WaylandConfig::removeOutput(WaylandOutput *output)
     }
 
     // remove the output from output mapping
-    Q_ASSERT(m_outputMap.take(output->id()) == output);
+    const auto removedOutput = m_outputMap.take(output->id());
+    Q_ASSERT(removedOutput == output); Q_UNUSED(removedOutput);
     m_screen->setOutputs(m_outputMap.values());
     delete output;
 
@@ -254,10 +255,18 @@ void WaylandConfig::removeOutput(WaylandOutput *output)
     }
 }
 
+bool WaylandConfig::isInitialized() const
+{
+    return !m_blockSignals
+            && m_registryInitialized
+            && m_initializingOutputs.isEmpty()
+            && m_outputMap.count() > 0
+            && m_outputManagement != nullptr;
+}
+
 void WaylandConfig::checkInitialized()
 {
-    if (!m_blockSignals && m_registryInitialized &&
-        m_initializingOutputs.isEmpty() && m_outputMap.count() && m_outputManagement != nullptr) {
+    if (isInitialized()) {
         m_screen->setOutputs(m_outputMap.values());
         Q_EMIT initialized();
     }
