@@ -40,7 +40,6 @@ XRandROutput::XRandROutput(xcb_randr_output_t id, XRandRConfig *config)
     , m_id(id)
     , m_primary(false)
     , m_type(KScreen::Output::Unknown)
-    , m_replicationSource(XCB_NONE)
     , m_crtc(nullptr)
 {
     init();
@@ -129,11 +128,6 @@ XRandRCrtc* XRandROutput::crtc() const
     return m_crtc;
 }
 
-xcb_randr_output_t XRandROutput::replicationSource() const
-{
-    return m_replicationSource;
-}
-
 void XRandROutput::update()
 {
     init();
@@ -327,69 +321,13 @@ bool isScaling(const xcb_render_transform_t &tr)
            tr.matrix31 == fZero && tr.matrix32 == fZero && tr.matrix33 == fOne;
 }
 
-xcb_render_transform_t zeroMatrix()
+xcb_render_transform_t zeroTransform()
 {
     return { DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
              DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
              DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0) };
 }
 
-xcb_render_transform_t XRandROutput::currentTransform() const
-{
-    auto cookie = xcb_randr_get_crtc_transform(XCB::connection(), m_crtc->crtc());
-    xcb_generic_error_t *error = nullptr;
-    auto *reply = xcb_randr_get_crtc_transform_reply(XCB::connection(), cookie, &error);
-    if (error) {
-        return zeroMatrix();
-    }
-
-    const xcb_render_transform_t transform = reply->pending_transform;
-    free(reply);
-    return transform;
-}
-
-QSizeF XRandROutput::scaledSize(xcb_render_transform_t transform) const
-{
-    const QSize ownSize = size();
-    if (!ownSize.isValid()) {
-        return QSize();
-    }
-
-    const qreal width = FIXED_TO_DOUBLE(transform.matrix11) * ownSize.width();
-    const qreal height = FIXED_TO_DOUBLE(transform.matrix22) * ownSize.height();
-
-    return QSizeF(width, height);
-}
-
-bool XRandROutput::isReplicaOf(XRandROutput *output, xcb_render_transform_t ownTransform) const
-{
-    if (output->id() == m_id) {
-        return false;
-    }
-    if (output->position() != position()) {
-        return false;
-    }
-    if (output->replicationSource() != XCB_NONE) {
-        return false;
-    }
-
-    const QSizeF sSize = scaledSize(ownTransform);
-    if (!sSize.isValid()) {
-        return false;
-    }
-
-    const auto outputTransform = output->currentTransform();
-    if (!isScaling(outputTransform)) {
-        return false;
-    }
-
-    if (sSize != output->scaledSize(outputTransform)) {
-        return false;
-    }
-
-    return true;
-}
-
 xcb_render_transform_t unityTransform()
 {
     return { DOUBLE_TO_FIXED(1), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0),
@@ -397,79 +335,70 @@ xcb_render_transform_t unityTransform()
              DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(0), DOUBLE_TO_FIXED(1) };
 }
 
-xcb_render_transform_t XRandROutput::getReplicationTransform(XRandROutput *source)
+xcb_render_transform_t XRandROutput::currentTransform() const
 {
-    if (!source) {
-        return unityTransform();
+    auto cookie = xcb_randr_get_crtc_transform(XCB::connection(), m_crtc->crtc());
+    xcb_generic_error_t *error = nullptr;
+    auto *reply = xcb_randr_get_crtc_transform_reply(XCB::connection(), cookie, &error);
+    if (error) {
+        return zeroTransform();
     }
 
-    const auto *sourceMode = source->currentMode();
-    const auto *ownMode = currentMode();
-    if (!sourceMode || !ownMode) {
-        return unityTransform();
-    }
-
-    QSize sourceSize = sourceMode->size();
-    QSize size = ownMode->size();
-
-    if (isHorizontal()) {
-        if (!source->isHorizontal()) {
-            sourceSize.transpose();
-        }
-    } else if (source->isHorizontal()) {
-        size.transpose();
-    }
-
-    const qreal widthFactor = sourceSize.width() / (qreal)size.width();
-    const qreal heightFactor = sourceSize.height() / (qreal)size.height();
-
-    xcb_render_transform_t transform = unityTransform();
-    transform.matrix11 = DOUBLE_TO_FIXED(widthFactor);
-    transform.matrix22 = DOUBLE_TO_FIXED(heightFactor);
-
+    const xcb_render_transform_t transform = reply->pending_transform;
+    free(reply);
     return transform;
 }
 
-bool XRandROutput::updateReplication()
+QSizeF XRandROutput::logicalSize() const
 {
-    XRandROutput *source = m_config->output(m_replicationSource);
-    if (source && (!source->isEnabled() || !source->isConnected())) {
-        return false;
+    const QSize modeSize = size();
+    if (!modeSize.isValid()) {
+        return QSize();
+    }
+
+    const xcb_render_transform_t transform = currentTransform();
+    const qreal width = FIXED_TO_DOUBLE(transform.matrix11) * modeSize.width();
+    const qreal height = FIXED_TO_DOUBLE(transform.matrix22) * modeSize.height();
+
+    return QSizeF(width, height);
+}
+
+void XRandROutput::updateLogicalSize(const KScreen::OutputPtr &output, XRandRCrtc *crtc)
+{
+    if (!crtc) {
+        // TODO: This is a workaround for now when updateLogicalSize is called on enabling the
+        //       output. At this point m_crtc is not yet set. Change the order in the future so
+        //       that the additional argument is not necessary anymore.
+        crtc = m_crtc;
+    }
+    const QSizeF logicalSize = output->explicitLogicalSize();
+    xcb_render_transform_t transform = unityTransform();
+
+    KScreen::ModePtr mode = output->currentMode() ? output->currentMode() : output->preferredMode();
+    if(mode && logicalSize.isValid()) {
+        QSize modeSize = mode->size();
+        if (!output->isHorizontal()) {
+            modeSize.transpose();
+        }
+
+        const qreal widthFactor = logicalSize.width() / (qreal)modeSize.width();
+        const qreal heightFactor = logicalSize.height() / (qreal)modeSize.height();
+        transform.matrix11 = DOUBLE_TO_FIXED(widthFactor);
+        transform.matrix22 = DOUBLE_TO_FIXED(heightFactor);
     }
 
-    xcb_render_transform_t transform = getReplicationTransform(source);
     QByteArray filterName(isScaling(transform) ? "bilinear" : "nearest");
 
     auto cookie = xcb_randr_set_crtc_transform_checked(XCB::connection(),
-                                                       m_crtc->crtc(),
+                                                       crtc->crtc(),
                                                        transform,
                                                        filterName.size(), filterName.data(),
                                                        0, nullptr);
     xcb_generic_error_t *error = xcb_request_check(XCB::connection(), cookie);
     if (error) {
-        qCDebug(KSCREEN_XRANDR) << "Error on replication transformation!";
+        qCDebug(KSCREEN_XRANDR) << "Error on logical size transformation!";
         free(error);
-        return false;
     }
-    free(error);
-    return true;
-}
-
-bool XRandROutput::setReplicationSource(xcb_randr_output_t source)
-{
-    if (!m_crtc) {
-        return false;
-    }
-    if (m_replicationSource == source) {
-        return true;
-    }
-    xcb_randr_output_t oldSource = m_replicationSource;
-    m_replicationSource = source;
-    if (!updateReplication()) {
-        m_replicationSource = oldSource;
-        return false;
-    }
-    return true;
 }
 
 KScreen::OutputPtr XRandROutput::toKScreenOutput() const
@@ -513,7 +442,7 @@ KScreen::OutputPtr XRandROutput::toKScreenOutput() const
             kscreenOutput->setRotation(rotation());
             kscreenOutput->setCurrentModeId(currentModeId());
         }
-        kscreenOutput->setReplicationSource(m_replicationSource);
+        // TODO: set logical size?
     }
 
     kscreenOutput->blockSignals(signalsBlocked);
