@@ -19,8 +19,8 @@
 #ifndef KSCREEN_CONFIGMONITOR_H
 #define KSCREEN_CONFIGMONITOR_H
 
-#include <QtCore/QObject>
-#include <QtCore/QPointer>
+#include <QObject>
+#include <QPointer>
 
 #include "config.h"
 #include "kscreen_export.h"
@@ -28,6 +28,9 @@
 namespace KScreen
 {
 
+class AbstractBackend;
+class BackendManager;
+
 class KSCREEN_EXPORT ConfigMonitor : public QObject
 {
     Q_OBJECT
@@ -43,10 +46,13 @@ Q_SIGNALS:
 
 private:
     explicit ConfigMonitor();
-    virtual ~ConfigMonitor();
+    ~ConfigMonitor() override;
 
     Q_DISABLE_COPY(ConfigMonitor)
 
+    friend BackendManager;
+    void connectInProcessBackend(KScreen::AbstractBackend *backend);
+
     class Private;
     Private * const d;
 
